@@ -22,11 +22,12 @@ const useStyles = createUseStyles({
         cursor: 'pointer',
         borderRadius: '2px',
         '&:hover': {
-            backgroundColor: (props) => `${props.outlineColor || 'var(--jp-layout-color2)'}`,
-            borderColor: (props) => `${props.outlineColor || 'var(--jp-border-color1)'}`
+            backgroundColor: (props) => `${props.hoverBackgroundColor || 'var(--jp-layout-color2)'}`,
+            borderColor: (props) => `${props.outlineColor || 'var(--jp-border-color1)'}`,
+            color: (props) => `${props.color || props.hoverTextColor || 'var(--jp-ui-font-color1)'}`
         },
         '&:active': {
-            backgroundColor: (props) => `${props.outlineColor || 'var(--jp-layout-color2)'}`
+            backgroundColor: (props) => `${props.hoverBackgroundColor || 'var(--jp-layout-color2)'}`
         },
         '&:disabled': {
             opacity: 0.5,
