@@ -1,6 +1,6 @@
 import { Store, useStoreState } from 'pullstate';
 import { UIStore } from '../stores/UIStore';
-import { COMM_NAME_KERNEL, COMM_NAME_FRONTEND, METADATA_KEY } from '../const';
+import { COMM_NAME_KERNEL, COMM_NAME_FRONTEND, METADATA_ATTACHMENTS_KEY } from '../const';
 import { actions } from '../utils/Actions';
 import { InjectNotebookToolbar } from '../InjectNotebookToolbar';
 import { computeCollectionState } from './Helpers';
@@ -137,7 +137,7 @@ export class NotebookListener {
         }
     }
     getAttachmentsFromMetadata(notebook) {
-        const rucioDidAttachments = notebook.model.metadata.get(METADATA_KEY);
+        const rucioDidAttachments = notebook.model.metadata.get(METADATA_ATTACHMENTS_KEY);
         const attachedDIDs = rucioDidAttachments;
         return attachedDIDs;
     }
