@@ -153,15 +153,17 @@ class RucioAPI:
             password = auth_config.get('password')
             account = auth_config.get('account')
             app_id = self.instance_config.get('app_id')
+            vo = self.instance_config.get('vo')
 
-            return authenticate_userpass(base_url=self.auth_url, username=username, password=password, account=account, app_id=app_id, rucio_ca_cert=self.rucio_ca_cert)
+            return authenticate_userpass(base_url=self.auth_url, username=username, password=password, account=account, vo=vo, app_id=app_id, rucio_ca_cert=self.rucio_ca_cert)
         elif auth_type == 'x509':
             cert_path = auth_config.get('certificate')
             key_path = auth_config.get('key')
             account = auth_config.get('account')
             app_id = self.instance_config.get('app_id')
+            vo = self.instance_config.get('vo')
 
-            return authenticate_x509(base_url=self.auth_url, cert_path=cert_path, key_path=key_path, account=account, app_id=app_id, rucio_ca_cert=self.rucio_ca_cert)
+            return authenticate_x509(base_url=self.auth_url, cert_path=cert_path, key_path=key_path, account=account, vo=vo, app_id=app_id, rucio_ca_cert=self.rucio_ca_cert)
 
         return None
 
